@@ -1,10 +1,6 @@
 library("matrixStats")
 library("utils")
 
-ctime <- function(which, t0, t1, t2, ...) {
-  cat(sprintf("%s: t1/t0=%.3g, t2/t0=%.3g, t2/t1=%.3g\n", which, (t1/t0)[3], (t2/t0)[3], (t2/t1)[3]))
-}
-
 rowRanksX <- function(x, ties.method, fcn, ...) {
   if (ties.method == "max") {
     y <- fcn(x, ties.method="max", flavor="v1")
@@ -38,29 +34,17 @@ for (mode in c("double", "integer")) {
   }
 
   for (MARGIN in 1:2) {
-    fcn <- if (MARGIN == 1) rowRanks else colRanks
+    fcn <- if (MARGIN == 1L) rowRanks else colRanks
 
     for (ties in c("max", "min", "average")) {
-      key <- sprintf("'%s' (mode='%s', MARGIN=%d)", ties, mode, MARGIN)
-
-      t0 <- system.time({
-        y0 <- t(apply(x, MARGIN=MARGIN, FUN=rank, na.last="keep", ties.method=ties))
-      })
-
+      y0 <- t(apply(x, MARGIN=MARGIN, FUN=rank, na.last="keep", ties.method=ties))
       if (ties != "average") {
-        t1 <- system.time({
-          y1 <- rowRanksX(x, ties.method=ties, fcn=fcn)
-        })
+        y1 <- rowRanksX(x, ties.method=ties, fcn=fcn)
         stopifnot(identical(y1,y0))
-      } else {
-        t1 <- NA
       }
 
-      t2 <- system.time({
-        y2 <- fcn(x, ties.method=ties, flavor="v2")
-      })
+      y2 <- fcn(x, ties.method=ties, flavor="v2")
       stopifnot(identical(y2,y0))
-      ctime(key, t0, t1, t2)
     } # for (ties ...)
 
   } # for (MARGIN ...)
